@@ -104,16 +104,40 @@ class FileManager(object):
             })
         return operations
 
+    def is_member(self, u_id, op_id):
+        """
+        op_id: operation id
+        u_id: user-id
+        """
+        # return true only if the user is a member
+        perm = Permission.query.filter_by(u_id=u_id, op_id=op_id).first()
+        if perm is None:
+            return False
+        return True
+
     def is_admin(self, u_id, op_id):
         """
         op_id: operation id
         u_id: user-id
         """
-        # return true only if the user is admin or creator
+        # return true only if the user is admin
         perm = Permission.query.filter_by(u_id=u_id, op_id=op_id).first()
-        if not perm:
+        if perm is None:
             return False
-        elif perm.access_level != "admin" and perm.access_level != "creator":
+        elif perm.access_level != "admin":
+            return False
+        return True
+
+    def is_creator(self, u_id, op_id):
+        """
+        op_id: operation id
+        u_id: user-id
+        """
+        # return true only if the user is creator
+        perm = Permission.query.filter_by(u_id=u_id, op_id=op_id).first()
+        if perm is None:
+            return False
+        elif perm.access_level != "creator":
             return False
         return True
 
@@ -123,10 +147,23 @@ class FileManager(object):
         u_id: user-id
         """
         # return true only if the user is collaborator
-        permi = Permission.query.filter_by(u_id=u_id, op_id=op_id).first()
-        if not permi:
+        perm = Permission.query.filter_by(u_id=u_id, op_id=op_id).first()
+        if perm is None:
             return False
-        elif permi.access_level != "collaborator":
+        elif perm.access_level != "collaborator":
+            return False
+        return True
+
+    def is_viewer(self, u_id, op_id):
+        """
+        op_id: operation id
+        u_id: user-id
+        """
+        # return true only if the user is viewer
+        perm = Permission.query.filter_by(u_id=u_id, op_id=op_id).first()
+        if perm is None:
+            return False
+        elif perm.access_level != "viewer":
             return False
         return True
 
@@ -136,7 +173,7 @@ class FileManager(object):
         u_id: user-id
         """
         perm = Permission.query.filter_by(u_id=u_id, op_id=op_id).first()
-        if not perm:
+        if perm is None:
             return False
         return perm.access_level
 
@@ -146,7 +183,7 @@ class FileManager(object):
         attribute: attribute to be changed, eg path
         user: logged in user
         """
-        if not self.is_admin(user.id, op_id):
+        if not self.is_admin(user.id, op_id) and not self.is_creator(user.id, op_id):
             return False
         operation = Operation.query.filter_by(id=op_id).first()
         if attribute == "path":
@@ -235,10 +272,10 @@ class FileManager(object):
         user: user of this request
         """
         perm = Permission.query.filter_by(u_id=user.id, op_id=op_id).first()
-        if not perm:
+        if perm is None:
             return False
         operation = Operation.query.filter_by(id=op_id).first()
-        if not operation:
+        if operation is None:
             return False
         with fs.open_fs(self.data_dir) as data:
             operation_file = data.open(fs.path.combine(operation.path, 'main.ftml'), 'r')
@@ -254,7 +291,7 @@ class FileManager(object):
         to render the recent changes.
         """
         perm = Permission.query.filter_by(u_id=user.id, op_id=op_id).first()
-        if not perm:
+        if perm is None:
             return False
         # Get all changes
         if named_version is None:
@@ -295,7 +332,7 @@ class FileManager(object):
         return change_content
 
     def set_version_name(self, ch_id, op_id, u_id, version_name):
-        if not (self.is_admin(u_id, op_id) or self.is_collaborator(u_id, op_id)):
+        if (not self.is_admin(u_id, op_id) and not self.is_creator(u_id, op_id)) or self.is_collaborator(u_id, op_id):
             return False
         Change.query\
             .filter(Change.id == ch_id)\
@@ -312,7 +349,7 @@ class FileManager(object):
         # ToDo a revert option, which removes only that commit's change
         """
         ch = Change.query.filter_by(id=ch_id).first()
-        if not self.is_admin(user.id, ch.op_id):
+        if not self.is_admin(user.id, ch.op_id) and not self.is_creator(user.id, ch.op_id):
             return False
         if ch is None:
             return False
@@ -338,7 +375,7 @@ class FileManager(object):
             return False
 
     def fetch_users_without_permission(self, op_id, u_id):
-        if not self.is_admin(u_id, op_id):
+        if not self.is_admin(u_id, op_id) and not self.is_creator(u_id, op_id):
             return False
 
         user_list = User.query\
@@ -350,7 +387,7 @@ class FileManager(object):
         return users
 
     def fetch_users_with_permission(self, op_id, u_id):
-        if not self.is_admin(u_id, op_id):
+        if not self.is_admin(u_id, op_id) and not self.is_creator(u_id, op_id):
             return False
 
         user_list = User.query\
@@ -363,7 +400,7 @@ class FileManager(object):
         return users
 
     def add_bulk_permission(self, op_id, user, new_u_ids, access_level):
-        if not self.is_admin(user.id, op_id):
+        if not self.is_admin(user.id, op_id) and not self.is_creator(user.id, op_id):
             return False
 
         new_permissions = []
@@ -379,7 +416,7 @@ class FileManager(object):
             return False
 
     def modify_bulk_permission(self, op_id, user, u_ids, new_access_level):
-        if not self.is_admin(user.id, op_id):
+        if not self.is_admin(user.id, op_id) and not self.is_creator(user.id, op_id):
             return False
 
         # TODO: Check whether we need synchronize_session False Or Fetch
@@ -396,8 +433,22 @@ class FileManager(object):
             return False
 
     def delete_bulk_permission(self, op_id, user, u_ids):
-        if not self.is_admin(user.id, op_id):
+        # if the user is not a member of the operation, return false
+        if not self.is_member(user.id, op_id):
             return False
+        elif not self.is_admin(user.id, op_id) and not self.is_creator(user.id, op_id):
+            # if the user is a member but non-admin and non-creator, and is trying to remove any other user
+            if len(u_ids) != 1 or user.id not in u_ids:
+                return False
+        else:
+            # if the user is admin or creator and is trying to remove a user not in this operation
+            for u_id in u_ids:
+                if not self.is_member(u_id, op_id):
+                    return False
+            if self.is_creator(user.id, op_id):
+                # if the user is creator and is trying to leave the operation, return false
+                if user.id in u_ids:
+                    return False
 
         Permission.query \
             .filter(Permission.op_id == op_id) \
@@ -408,11 +459,11 @@ class FileManager(object):
         return True
 
     def import_permissions(self, import_op_id, current_op_id, u_id):
-        if not self.is_admin(u_id, current_op_id):
-            return False, None, "Not an admin of this operation"
+        if not self.is_creator(u_id, current_op_id) and not self.is_admin(u_id, current_op_id):
+            return False, None, "Not the creator or admin of this operation"
 
         perm = Permission.query.filter_by(u_id=u_id, op_id=import_op_id).first()
-        if not perm:
+        if perm is None:
             return False, None, "Not a member of this operation"
 
         existing_perms = Permission.query \
