@@ -28,7 +28,7 @@ import pycountry
 from mslib.msui.mss_qt import ui_airdata_dockwidget as ui
 from PyQt5 import QtWidgets, QtCore
 from mslib.utils.config import save_settings_qsettings, load_settings_qsettings
-from mslib.utils.airdata import _airspace_cache, update_airspace, get_airports
+from mslib.utils.airdata import get_available_airspaces, update_airspace, get_airports
 
 
 class AirdataDockwidget(QtWidgets.QWidget, ui.Ui_AirdataDockwidget):
@@ -41,9 +41,11 @@ class AirdataDockwidget(QtWidgets.QWidget, ui.Ui_AirdataDockwidget):
         code_to_name = {country.alpha_2.lower(): country.name for country in pycountry.countries}
         self.cbAirspaces.addItems([f"{code_to_name.get(airspace[0].split('_')[0], 'Unknown')} "
                                    f"{airspace[0].split('_')[0]}"
-                                   for airspace in _airspace_cache])
+                                   for airspace in get_available_airspaces()])
         self.cbAirportType.addItems(["small_airport", "medium_airport", "large_airport", "heliport", "balloonport",
                                      "seaplane_base", "closed"])
+        self.cbAirportType.empty_text = "Click here to select airports..."
+        self.cbAirspaces.empty_text = "Click here to select airspaces..."
 
         self.settings_tag = "airdatadock"
         settings = load_settings_qsettings(self.settings_tag, {"draw_airports": False, "draw_airspaces": False,
@@ -56,8 +58,12 @@ class AirdataDockwidget(QtWidgets.QWidget, ui.Ui_AirdataDockwidget):
                                                                           self.cbAirspaces.currentData()]))
         self.btApply.clicked.connect(self.redraw_map)
 
+        self.cbAirspaces.currentTextChanged.connect(self.adjust_ui_airspaces)
+        self.cbAirportType.currentTextChanged.connect(self.adjust_ui_airports)
+
         self.cbDrawAirports.setChecked(settings["draw_airports"])
         self.cbDrawAirspaces.setChecked(settings["draw_airspaces"])
+
         for airspace in settings["airspaces"]:
             i = self.cbAirspaces.findText(airspace)
             if i != -1:
@@ -71,6 +77,24 @@ class AirdataDockwidget(QtWidgets.QWidget, ui.Ui_AirdataDockwidget):
         self.sbFrom.setValue(settings["filter_from"])
         self.sbTo.setValue(settings["filter_to"])
 
+    def adjust_ui_airspaces(self):
+        """
+        Disables and unchecks, or vice versa, airspace UI elements depending on the current user selection
+        """
+        airspaces_enabled = len(self.cbAirspaces.currentData()) > 0
+        self.cbDrawAirspaces.setChecked(airspaces_enabled)
+        self.cbDrawAirspaces.setEnabled(airspaces_enabled)
+        self.btDownloadAsp.setEnabled(airspaces_enabled)
+
+    def adjust_ui_airports(self):
+        """
+        Disables and unchecks, or vice versa, airport UI elements depending on the current user selection
+        """
+        airports_enabled = len(self.cbAirportType.currentData()) > 0
+        self.cbDrawAirports.setChecked(airports_enabled)
+        self.cbDrawAirports.setEnabled(airports_enabled)
+        self.btDownload.setEnabled(airports_enabled)
+
     def redraw_map(self):
         if self.view.map is not None:
             self.view.map.set_draw_airports(self.cbDrawAirports.isChecked(), port_type=self.cbAirportType.currentData())
