@@ -9,7 +9,7 @@
     This file is part of mss.
 
     :copyright: Copyright 2017 Joern Ungermann
-    :copyright: Copyright 2017-2021 by the mss team, see AUTHORS.
+    :copyright: Copyright 2017-2022 by the mss team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -24,8 +24,6 @@
     See the License for the specific language governing permissions and
     limitations under the License.
 """
-import fs
-import logging
 import collections
 
 from matplotlib.collections import LineCollection
@@ -34,10 +32,10 @@ import numpy as np
 from skyfield.api import Loader, Topos, utc
 import skyfield_data
 
-from mslib.msui.constants import MSS_CONFIG_PATH
 from PyQt5 import QtGui, QtWidgets
 from mslib.msui.mss_qt import ui_remotesensing_dockwidget as ui
-from mslib.utils import jsec_to_datetime, datetime_to_jsec, get_distance, rotate_point, fix_angle
+from mslib.utils.time import jsec_to_datetime, datetime_to_jsec
+from mslib.utils.coordinate import get_distance, rotate_point, fix_angle
 
 
 EARTH_RADIUS = 6371.
@@ -57,22 +55,10 @@ class RemoteSensingControlWidget(QtWidgets.QWidget, ui.Ui_RemoteSensingDockWidge
         self.setupUi(self)
 
         self.view = view
-        if '://' in MSS_CONFIG_PATH:
-            try:
-                _fs = fs.open_fs(MSS_CONFIG_PATH)
-                download_path = _fs.getsyspath("")
-            except fs.errors.CreateFailed:
-                logging.error(f'Make sure that the FS url "{MSS_CONFIG_PATH}" exists')
-            except fs.opener.errors.UnsupportedProtocol:
-                logging.error(f'FS url "{MSS_CONFIG_PATH}" not supported')
-        else:
-            download_path = MSS_CONFIG_PATH
-
-        self.load = Loader(download_path, verbose=False)
         self.load_bsp = Loader(skyfield_data.get_skyfield_data_path(), verbose=False)
 
-        self.timescale = self.load.timescale(builtin=True)
         self.planets = self.load_bsp('de421.bsp')
+        self.timescale = self.load_bsp.timescale(builtin=True)
 
         button = self.btTangentsColour
         palette = QtGui.QPalette(button.palette())
@@ -239,7 +225,7 @@ class RemoteSensingControlWidget(QtWidgets.QWidget, ui.Ui_RemoteSensingDockWidge
         for i, (lon, lat) in enumerate(zip(solar_x, solar_y)):
             points.append([[lon, lat]])  # append double-list for later concatenation
             if old_wp is not None:
-                wp_dist = get_distance((old_wp[0], old_wp[1]), (lat, lon)) * 1000.
+                wp_dist = get_distance(old_wp[0], old_wp[1], lat, lon) * 1000.
                 total_distance += wp_dist
             old_wp = (lat, lon)
         vals = []
