@@ -10,7 +10,7 @@
 
     :copyright: Copyright 2008-2014 Deutsches Zentrum fuer Luft- und Raumfahrt e.V.
     :copyright: Copyright 2017 Joern Ungermann
-    :copyright: Copyright 2016-2021 by the mss team, see AUTHORS.
+    :copyright: Copyright 2016-2022 by the mss team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -450,8 +450,9 @@ class Test_WMS(object):
         assert not os.path.exists(file)
         mslib.mswms.wms.server.generate_gallery(generate_code=False, plot_list=linear_plots)
         assert not os.path.exists(os.path.join(tempdir, "code"))
-        assert os.path.exists(file)
-        assert modified_at == os.path.getmtime(file2)
+        assert os.path.exists(file), file
+        assert modified_at == os.path.getmtime(file2), \
+            (modified_at, os.path.getmtime(file2))
 
         mslib.mswms.wms.server.generate_gallery(clear=True, create=True, plot_list=linear_plots)
         assert modified_at != os.path.getmtime(file2)
